
.onLoad <- function(lib, pkg) {
      library.dynam("boolfun", pkg, lib)
}

